==> ocre_v0_037.tgz: ocre-0.037/ocre/src/labores.c <==

#include <libintl.h>
#include <locale.h>
#define _(mens) gettext(mens)
#define N_(mens) (mens)

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtkmain.h>

//#include "id3/arbolesid3.h"
#include "dcsw/treesdcsw.h"
#include "arbolesOcre.h"
#include "config.h"
#include "convcar.h"
#include "diccionarios.h"
#include "distrib2.h"
#include "estadDistancs.h"
#include "glifos.h"
#include "glifoscc.h"
#include "idiom.h"
#include "imag.h"
#include "imagio.h"
#include "lectura.h"
#include "mayusMinus.h"
#include "opcns.h"
#include "parecido.h"
#include "reconoce.h"

// comienzo_local
#include "opcionesp.h"
#include "segmenta3.h"
// fin_local

extern int optind;

// -------- -------- -------- -------- --------

void inicio0 ()
{
  setlocale (LC_ALL, "");
  bindtextdomain("p1", "/usr/share/locale");
  textdomain ("ocre");
}

// -------- -------- -------- -------- --------

void tomaOpciones (int argc, char **argv)
{
  misopc (argc, argv);
}

// -------- -------- -------- -------- --------

void leeArboledas ()
{
  char dArb [256];
  strcpy (dArb, a_valor);
  if (l_opcion)
    if (l_valor_idiom == idiom_rus ) {
      strcat (dArb, "Cyrillic");
      }
  // printf ("%s\n", dArb);
  leeArboles (dArb);
  leeArbolesCur (DIRLIB_CUR);
  leeArbolesW (DIRLIBW);
}

void inicioModulos (int argc, char **argv)
{
  inicia_umbralComparaSuperp ();
  lglmuestra = listadglifoNueva ();
  leeArboledas ();
  leemayusMinusYrev (DIRCONV);
  leechpuntua       (DIRCONV);
  leeTutf2salida (a_valor);
  if (D_opcion)
    abre_diccionarios ("es_ES");  // corregir, es_ES sobra
  gtk_init (&argc, &argv);
}

// -------- -------- -------- -------- --------

// comienzo_local

void estadisticas1 (tglifo  glifo)
{
  int * cntglifo;
  int * cnrecon;
  int * cnreconDcsw;
  int * cnreconComp;
  printf("\n");
  // describeGlifo(glifo,2);
  cuentaTiposenGlifo (&cntglifo, glifo);
  imprimeRecuentoTiposenGlifo (cntglifo);
  printf("\n");
  cuentaTiposReconocimientos (&cnrecon, glifo);
  imprimeRecuentoReconocimientos (cnrecon);
  printf("\n");
  cuentaTiposReconocimientosDcsw (&cnreconDcsw, glifo);
  imprimeRecuentoReconocimientosDcsw (cnreconDcsw);
  imprimeTasaReconocimientosDcsw (cnreconDcsw, cntglifo);
  printf("\n");
  cuentaTiposReconocimientosComp (&cnreconComp, glifo);
  imprimeRecuentoReconocimientosComp (cnreconComp);
  //
  imprimeTasaReconocimientosComp (cnreconComp, cntglifo);
}

void estadisticas (tglifo * glifoG, int nimags)
{
  int i;
  tglifo glifoG1;
  if (e_opcion) {
    for (i=0; i<nimags; i++)
      estadisticas1 (glifoG[i]);
    if (i>1){
      glifoG1 = glifoDeArrayDeGlifos (glifoG, nimags);
      // describeGlifo(glifoG1,1);
      printf ("\nTotal:");
      estadisticas1 (glifoG1);
      }
    }
  printf ("preguntas: %4d\n", cuantasPreguntas());
}
// fin_local 

void leeImagenes (timagf **nimag,  tvent **nvent, int nimags, char **argv)
{
  int i;
  timagf * imag;
  timagf   imagi;
  tvent  * vent;
  imag   = (timagf *) malloc (nimags * sizeof(timagf)) ;
  vent   = (tvent *)  malloc (nimags * sizeof(tvent)) ;
  for (i=0; i < nimags; i++) {
    leeImagen (& imagi, argv[i+optind]);
    // vent[i] = imag[i]->ven0;
    //  para no tener problemas con las comparaciones de glifos
    // ventanaDeVentana ( &(vent[i]), imagi->ven0, 2, 2, imagi->tx - 4, imagi->ty - 4); 
    ventanaDeVentana ( &(vent[i]), imagi->ven0, 1, 1, imagi->tx - 2, imagi->ty - 2); 
    imag[i] = imagi;
    }
  *nimag = imag;
  *nvent = vent;
}

void leedeVentanas (tglifo **nglifoG, tvent *vent, int nimags, int nc)
{
  int i;
  tglifo * glifoG;
// comienzo_local
  ttdocum  tdocum; 
// fin_local
  glifoG = (tglifo *) malloc (nimags * sizeof(tglifo)) ;
  for (i=0; i < nimags; i++) {
// comienzo_local
    opcionesP (vent[0]);
    tipoDocumento (&tdocum, vent[i]);
    if (P_opcion || (tdocum == tdocumTabloide)) {
      segmentayLeeTabloide (&glifoG[i], vent[i], &nc);
      }
    else
  // fin_local 
      segmReconoceyRepasaG (&(glifoG[i]), vent[i], &nc);
    }
  *nglifoG = glifoG;
}

void leyendo (int argc, char **argv)
{
  int nimags;
  timagf * imag;
  tvent  * vent;
  tglifo * glifoG;
  nimags = argc - optind ;
  if (nimags == 0){
    printf (_("%s: missing the image file\n"), argv[0]);
    exit (1);
    }
  leeImagenes (&imag, &vent, nimags, argv);
  leedeVentanas (&glifoG, vent, nimags, n_valori);
// comienzo_local 
  estadisticas (glifoG, nimags);
//
//  estad_distans_Todo (glifoG);
// fin_local
}

==> ocre_v0_041.tgz: ocre-0.041/ocre/src/labores.c <==

#include <libintl.h>
#include <locale.h>
#define _(mens) gettext(mens)
#define N_(mens) (mens)

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtkmain.h>

//#include "id3/arbolesid3.h"
#include "dcsw/treesdcsw.h"
#include "arbolesOcre.h"
#include "config.h"
#include "convcar.h"
#include "diccionarios.h"
#include "distrib2.h"
#include "estadDistancs.h"
#include "glifos.h"
#include "glifoscc.h"
#include "idiom.h"
#include "imag.h"
#include "imagio.h"
#include "lectura.h"
#include "mayusMinus.h"
#include "opcns.h"
#include "parecido.h"
#include "reconoce.h"

// comienzo_local
#include "opcionesp.h"
#include "segmenta3.h"
// fin_local

extern int optind;

// -------- -------- -------- -------- --------

void inicio0 ()
{
  setlocale (LC_ALL, "");
  bindtextdomain("p1", "/usr/share/locale");
  textdomain ("ocre");
}

// -------- -------- -------- -------- --------

void tomaOpciones (int argc, char **argv)
{
  misopc (argc, argv);
}

// -------- -------- -------- -------- --------

void leeArboledas ()
{
  char dArb [256];
  strcpy (dArb, a_valor);
  if (l_opcion)
    if (l_valor_idiom == idiom_rus ) {
      strcat (dArb, "Cyrillic");
      }
  // printf ("%s\n", dArb);
  leeArboles (dArb);
  leeArbolesCur (DIRLIB_CUR);
  leeArbolesW (DIRLIBW);
}

void inicioModulos (int argc, char **argv)
{
  inicia_umbralComparaSuperp ();
  lglmuestra = listadglifoNueva ();
  leeArboledas ();
  leemayusMinusYrev (DIRCONV);
  leechpuntua       (DIRCONV);
  leeTutf2salida (a_valor);
  if (D_opcion)
    abre_diccionarios ("es_ES");  // corregir, es_ES sobra
  if (! s_opcion)
    gtk_init (&argc, &argv);
}

// -------- -------- -------- -------- --------

// comienzo_local

void estadisticas1 (tglifo  glifo)
{
  int * cntglifo;
  int * cnrecon;
  int * cnreconDcsw;
  int * cnreconComp;
  printf("\n");
  // describeGlifo(glifo,2);
  cuentaTiposenGlifo (&cntglifo, glifo);
  imprimeRecuentoTiposenGlifo (cntglifo);
  printf("\n");
  cuentaTiposReconocimientos (&cnrecon, glifo);
  imprimeRecuentoReconocimientos (cnrecon);
  printf("\n");
  cuentaTiposReconocimientosDcsw (&cnreconDcsw, glifo);
  imprimeRecuentoReconocimientosDcsw (cnreconDcsw);
  imprimeTasaReconocimientosDcsw (cnreconDcsw, cntglifo);
  printf("\n");
  cuentaTiposReconocimientosComp (&cnreconComp, glifo);
  imprimeRecuentoReconocimientosComp (cnreconComp);
  //
  imprimeTasaReconocimientosComp (cnreconComp, cntglifo);
}

void estadisticas (tglifo * glifoG, int nimags)
{
  int i;
  tglifo glifoG1;
  if (e_opcion) {
    for (i=0; i<nimags; i++)
      estadisticas1 (glifoG[i]);
    if (i>1){
      glifoG1 = glifoDeArrayDeGlifos (glifoG, nimags);
      // describeGlifo(glifoG1,1);
      printf ("\nTotal:");
      estadisticas1 (glifoG1);
      }
    }
  printf ("preguntas: %4d\n", cuantasPreguntas());
}
// fin_local 

void leeImagenes (timagf **nimag,  tvent **nvent, int nimags, char **argv)
{
  int i;
  timagf * imag;
  timagf   imagi;
  tvent  * vent;
  imag   = (timagf *) malloc (nimags * sizeof(timagf)) ;
  vent   = (tvent *)  malloc (nimags * sizeof(tvent)) ;
  for (i=0; i < nimags; i++) {
    leeImagen (& imagi, argv[i+optind]);
    // vent[i] = imag[i]->ven0;
    //  para no tener problemas con las comparaciones de glifos
    // ventanaDeVentana ( &(vent[i]), imagi->ven0, 2, 2, imagi->tx - 4, imagi->ty - 4); 
    ventanaDeVentana ( &(vent[i]), imagi->ven0, 1, 1, imagi->tx - 2, imagi->ty - 2); 
    imag[i] = imagi;
    }
  *nimag = imag;
  *nvent = vent;
}

void leedeVentanas (tglifo **nglifoG, tvent *vent, int nimags, int nc)
{
  int i;
  tglifo * glifoG;
// comienzo_local
  ttdocum  tdocum; 
  tvent ventil;
// fin_local
  glifoG = (tglifo *) malloc (nimags * sizeof(tglifo)) ;
  for (i=0; i < nimags; i++) {
    eliminaBordes (&ventil, vent[i]);
// comienzo_local
    opcionesP (vent[0]);
    // tipoDocumento (&tdocum, vent[i]);
    tipoDocumento (&tdocum, ventil);
    if (P_opcion || (tdocum == tdocumTabloide)) {
      // segmentayLeeTabloide (&glifoG[i], vent[i], &nc);
      segmentayLeeTabloide (&glifoG[i], ventil, &nc);
      }
    else
  // fin_local 
      // segmReconoceyRepasaG (&(glifoG[i]), vent[i], &nc);
      segmReconoceyRepasaG (&(glifoG[i]), ventil, &nc);
    }
  *nglifoG = glifoG;
}

void leyendo (int argc, char **argv)
{
  int nimags;
  timagf * imag;
  tvent  * vent;
  tglifo * glifoG;
  nimags = argc - optind ;
  if (nimags == 0){
    printf (_("%s: missing the image file\n"), argv[0]);
    exit (1);
    }
  leeImagenes (&imag, &vent, nimags, argv);
  leedeVentanas (&glifoG, vent, nimags, n_valori);
// comienzo_local 
  estadisticas (glifoG, nimags);
//
//  estad_distans_Todo (glifoG);
// fin_local
}
